@@ -1,6 +1,7 @@
 import urllib
 
-from github2.core import GithubCommand, BaseData, Attribute, DateAttribute
+from github2.core import (GithubCommand, BaseData, Attribute, DateAttribute,
+                          repr_string, requires_auth)
 
 
 class Issue(BaseData):
@@ -20,7 +21,7 @@ class Issue(BaseData):
     pull_request_url = Attribute("URL for the issue's related pull request.")
 
     def __repr__(self):
-        return "<Issue: %s>" % self.title.encode('utf-8')
+        return "<Issue: %s>" % repr_string(self.title)
 
 
 class Comment(BaseData):
@@ -31,7 +32,7 @@ class Comment(BaseData):
     user = Attribute("The username of the user that created this comment.")
 
     def __repr__(self):
-        return "<Comment: %s>" % self.body
+        return "<Comment: %s>" % repr_string(self.body)
 
 
 class Issues(GithubCommand):
@@ -88,6 +89,7 @@ class Issues(GithubCommand):
         return self.get_value("show", project, str(number),
                               filter="issue", datatype=Issue)
 
+    @requires_auth
     def open(self, project, title, body):
         """Open up a new issue.
 
@@ -99,6 +101,7 @@ class Issues(GithubCommand):
         return self.get_value("open", project, post_data=issue_data,
                               filter="issue", datatype=Issue)
 
+    @requires_auth
     def close(self, project, number):
         """Close an issue
 
@@ -108,6 +111,7 @@ class Issues(GithubCommand):
         return self.get_value("close", project, str(number), filter="issue",
                               datatype=Issue, method="POST")
 
+    @requires_auth
     def reopen(self, project, number):
         """Reopen a closed issue
 
@@ -119,6 +123,7 @@ class Issues(GithubCommand):
         return self.get_value("reopen", project, str(number), filter="issue",
                               datatype=Issue, method="POST")
 
+    @requires_auth
     def edit(self, project, number, title, body):
         """Edit an existing issue
 
@@ -134,6 +139,7 @@ class Issues(GithubCommand):
                               post_data=issue_data, filter="issue",
                               datatype=Issue)
 
+    @requires_auth
     def add_label(self, project, number, label):
         """Add a label to an issue
 
@@ -141,9 +147,10 @@ class Issues(GithubCommand):
         :param int number: issue number in the Github database
         :param str label: label to attach to issue
         """
-        return self.make_request("label/add", project, label, str(number),
-                                 filter="labels", method="POST")
+        return self.get_values("label/add", project, label, str(number),
+                               filter="labels", method="POST")
 
+    @requires_auth
     def remove_label(self, project, number, label):
         """Remove an existing label from an issue
 
@@ -151,9 +158,10 @@ class Issues(GithubCommand):
         :param int number: issue number in the Github database
         :param str label: label to remove from issue
         """
-        return self.make_request("label/remove", project, label, str(number),
-                                 filter="labels", method="POST")
+        return self.get_values("label/remove", project, label, str(number),
+                               filter="labels", method="POST")
 
+    @requires_auth
     def comment(self, project, number, comment):
         """Comment on an issue.
 
@@ -162,9 +170,9 @@ class Issues(GithubCommand):
         :param str comment: comment to attach to issue
         """
         comment_data = {'comment': comment}
-        return self.make_request("comment", project, str(number),
-                                 post_data=comment_data,
-                                 filter='comment')
+        return self.get_value("comment", project, str(number),
+                              post_data=comment_data, filter='comment',
+                              datatype=Comment)
 
     def comments(self, project, number):
         """View comments on an issue.
