@@ -1,4 +1,8 @@
-from github2.core import BaseData, GithubCommand, Attribute, DateAttribute
+from github2.core import (BaseData, GithubCommand, Attribute, DateAttribute,
+                          requires_auth)
+
+from github2.users import User
+
 
 class Repository(BaseData):
     name = Attribute("Name of repository.")
@@ -19,13 +23,14 @@ class Repository(BaseData):
     has_wiki = Attribute("If True, this repository has a wiki.")
     has_issues = Attribute("If True, this repository has an issue tracker.")
     language = Attribute("Primary language for the repository.")
+    parent = Attribute("The parent project of this fork.")
 
     def _project(self):
         return self.owner + "/" + self.name
     project = property(_project)
 
     def __repr__(self):
-        return "<Repository: %s>" % (self._project())
+        return "<Repository: %s>" % self.project
 
 
 class Repositories(GithubCommand):
@@ -36,7 +41,8 @@ class Repositories(GithubCommand):
 
         :param str query: term to search issues for
         """
-        return self.make_request("search", query, filter="repositories")
+        return self.get_values("search", query, filter="repositories",
+                               datatype=Repository)
 
     def show(self, project):
         """Get repository object for project.
@@ -46,12 +52,14 @@ class Repositories(GithubCommand):
         return self.get_value("show", project, filter="repository",
                               datatype=Repository)
 
+    @requires_auth
     def pushable(self):
         """Return a list of repos you can push to that are not your own.
 
         .. versionadded:: 0.3.0
         """
-        return self.get_values("pushable", filter="repositories", datatype=Repository)
+        return self.get_values("pushable", filter="repositories",
+                               datatype=Repository)
 
 
     def list(self, user=None):
@@ -68,20 +76,25 @@ class Repositories(GithubCommand):
         return self.get_values("show", user, filter="repositories",
                                datatype=Repository)
 
+    @requires_auth
     def watch(self, project):
         """Watch a project
 
         :param str project: GitHub project
         """
-        return self.make_request("watch", project)
+        return self.get_value("watch", project, filter='repository',
+                              datatype=Repository)
 
+    @requires_auth
     def unwatch(self, project):
         """Unwatch a project
 
         :param str project: GitHub project
         """
-        return self.make_request("unwatch", project)
+        return self.get_value("unwatch", project, filter='repository',
+                              datatype=Repository)
 
+    @requires_auth
     def fork(self, project):
         """Fork a project
 
@@ -90,6 +103,7 @@ class Repositories(GithubCommand):
         return self.get_value("fork", project, filter="repository",
                               datatype=Repository)
 
+    @requires_auth
     def create(self, project, description=None, homepage=None, public=True):
         """Create a repository
 
@@ -103,6 +117,7 @@ class Repositories(GithubCommand):
         return self.get_value("create", post_data=repo_data,
                               filter="repository", datatype=Repository)
 
+    @requires_auth
     def delete(self, project):
         """Delete a repository
 
@@ -113,6 +128,7 @@ class Repositories(GithubCommand):
         result = self.make_request("delete", project, method="POST")
         self.make_request("delete", project, post_data=result)
 
+    @requires_auth
     def set_private(self, project):
         """Mark repository as private
 
@@ -120,6 +136,7 @@ class Repositories(GithubCommand):
         """
         return self.make_request("set/private", project)
 
+    @requires_auth
     def set_public(self, project):
         """Mark repository as public
 
@@ -132,17 +149,20 @@ class Repositories(GithubCommand):
 
         :param str project: GitHub project
         """
-        return self.make_request("show", project, "collaborators",
-                                 filter="collaborators")
+        return self.get_values("show", project, "collaborators",
+                               filter="collaborators")
 
+    @requires_auth
     def add_collaborator(self, project, username):
         """Adds an add_collaborator to a repo
 
         :param str project: Github project
         :param str username: Github user to add as collaborator
         """
-        return self.make_request("collaborators", project, "add", username)
+        return self.make_request("collaborators", project, "add", username,
+                                 method="POST")
 
+    @requires_auth
     def remove_collaborator(self, project, username):
         """Removes an add_collaborator from a repo
 
@@ -157,38 +177,36 @@ class Repositories(GithubCommand):
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "network", filter="network")
+        return self.get_values("show", project, "network", filter="network",
+                               datatype=Repository)
 
     def languages(self, project):
         """Get programming language data for project
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "languages",
-                                 filter="languages")
+        return self.get_values("show", project, "languages", filter="languages")
 
     def tags(self, project):
         """Get tags for project
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "tags", filter="tags")
+        return self.get_values("show", project, "tags", filter="tags")
 
     def branches(self, project):
         """Get branch names for project
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "branches",
-                                 filter="branches")
+        return self.get_values("show", project, "branches", filter="branches")
 
     def watchers(self, project):
         """Get list of watchers for project
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "watchers",
-                                 filter="watchers")
+        return self.get_values("show", project, "watchers", filter="watchers")
 
     def watching(self, for_user=None):
         """Lists all the repos a user is watching
@@ -204,5 +222,5 @@ class Repositories(GithubCommand):
 
         :param str project: Github project
         """
-        return self.make_request("show", project, "contributors",
-                           filter="contributors")
+        return self.get_values("show", project, "contributors",
+                               filter="contributors", datatype=User)
