@@ -1,16 +1,13 @@
 import datetime
+import logging
 import re
-import sys
 import time
 import httplib2
 try:
     import json as simplejson  # For Python 2.6
 except ImportError:
     import simplejson
-try:
-    import socks  # SOCKS support may not be installed
-except ImportError:
-    socks = None
+from os import path
 from urlparse import (urlsplit, urlunsplit)
 try:
     from urlparse import parse_qs
@@ -22,6 +19,9 @@ from urllib import urlencode, quote
 #: Hostname for API access
 GITHUB_URL = "https://github.com"
 
+#: Logger for requests module
+LOGGER = logging.getLogger('github2.request')
+
 
 def charset_from_headers(headers):
     """Parse charset from headers
@@ -49,8 +49,8 @@ class GithubRequest(object):
     GithubError = GithubError
 
     def __init__(self, username=None, api_token=None, url_prefix=None,
-            debug=False, requests_per_second=None, access_token=None,
-            cache=None, proxy_host=None, proxy_port=None):
+                 requests_per_second=None, access_token=None,
+                 cache=None, proxy_host=None, proxy_port=None):
         """Make an API request.
 
         :see: :class:`github2.client.Github`
@@ -59,7 +59,6 @@ class GithubRequest(object):
         self.api_token = api_token
         self.access_token = access_token
         self.url_prefix = url_prefix
-        self.debug = debug
         if requests_per_second is None:
             self.delay = 0
         else:
@@ -71,15 +70,15 @@ class GithubRequest(object):
                 "api_version": self.api_version,
                 "api_format": self.api_format,
             }
+        digicert_ha_cert = path.join(path.dirname(path.abspath(__file__ )),
+                                     "DigiCert_High_Assurance_EV_Root_CA.crt")
         if proxy_host is None:
-            self._http = httplib2.Http(cache=cache)
-        elif proxy_host and socks is None:
-            raise GithubError('Proxy support missing.  '
-                              'Install a Python SOCKS library.')
+            self._http = httplib2.Http(cache=cache, ca_certs=digicert_ha_cert)
         else:
-            proxy_info = httplib2.ProxyInfo(socks.PROXY_TYPE_HTTP,
+            proxy_info = httplib2.ProxyInfo(httplib2.socks.PROXY_TYPE_HTTP,
                                             proxy_host, proxy_port)
-            self._http = httplib2.Http(proxy_info=proxy_info, cache=cache)
+            self._http = httplib2.Http(proxy_info=proxy_info, cache=cache,
+                                       ca_certs=digicert_ha_cert)
 
     def encode_authentication_data(self, extra_post_data):
         if self.access_token:
@@ -117,8 +116,7 @@ class GithubRequest(object):
             since_last_in_seconds = (since_last.days * 24 * 60 * 60) + since_last.seconds + (since_last.microseconds/1000000.0)
             if since_last_in_seconds < self.delay:
                 duration = self.delay - since_last_in_seconds
-                if self.debug:
-                    sys.stderr.write("delaying API call %s\n" % duration)
+                LOGGER.warning("delaying API call %s second(s)", duration)
                 time.sleep(duration)
 
         extra_post_data = extra_post_data or {}
@@ -133,7 +131,6 @@ class GithubRequest(object):
         scheme, netloc, path, query, fragment = urlsplit(url)
         post_data = None
         headers = self.http_headers
-        headers["Accept"] = "text/html"
         method = method.upper()
         if extra_post_data or method == "POST":
             post_data = self.encode_authentication_data(extra_post_data)
@@ -142,9 +139,9 @@ class GithubRequest(object):
             query = self.encode_authentication_data(parse_qs(query))
         url = urlunsplit((scheme, netloc, path, query, fragment))
         response, content = self._http.request(url, method, post_data, headers)
-        if self.debug:
-            sys.stderr.write("URL:[%s] POST_DATA:%s RESPONSE_TEXT: [%s]\n" % (
-                             url, post_data, content))
+        if LOGGER.isEnabledFor(logging.DEBUG):
+            logging.debug("URL: %r POST_DATA: %r RESPONSE_TEXT: %r", url,
+                          post_data, content)
         if response.status >= 400:
             raise RuntimeError("unexpected response from github.com %d: %r" % (
                                response.status, content))
@@ -156,5 +153,7 @@ class GithubRequest(object):
 
     @property
     def http_headers(self):
-        return {"User-Agent": "pygithub2 v1",
-                "Accept-Encoding": "application/json"}
+        return {
+            "User-Agent": "pygithub2 v1",
+            "Accept": "application/json",
+        }
