@@ -1,4 +1,5 @@
-from github2.core import BaseData, GithubCommand, DateAttribute, Attribute
+from github2.core import (BaseData, GithubCommand, DateAttribute, Attribute,
+                          enhanced_by_auth, requires_auth)
 import urllib
 
 
@@ -33,7 +34,7 @@ class User(BaseData):
         return self.plan is not None
 
     def __repr__(self):
-        return "<User: %s>" % (self.login)
+        return "<User: %s>" % self.login
 
 
 class Users(GithubCommand):
@@ -54,6 +55,7 @@ class Users(GithubCommand):
         """
         return self.get_value("email", query, filter="user", datatype=User)
 
+    @enhanced_by_auth
     def show(self, username):
         """Get information on Github user
 
@@ -69,25 +71,27 @@ class Users(GithubCommand):
 
         :param str username: Github user name
         """
-        return self.make_request("show", username, "followers", filter="users")
+        return self.get_values("show", username, "followers", filter="users")
 
     def following(self, username):
         """Get list of users a Github user is following
 
         :param str username: Github user name
         """
-        return self.make_request("show", username, "following", filter="users")
+        return self.get_values("show", username, "following", filter="users")
 
+    @requires_auth
     def follow(self, other_user):
         """Follow a Github user
 
         :param str other_user: Github user name
         """
-        return self.make_request("follow", other_user)
+        return self.get_values("follow", other_user, method="POST")
 
+    @requires_auth
     def unfollow(self, other_user):
         """Unfollow a Github user
 
         :param str other_user: Github user name
         """
-        return self.make_request("unfollow", other_user)
+        return self.get_values("unfollow", other_user, method="POST")
