@@ -1,6 +1,7 @@
 import _setup
 
 import os
+import sys
 import unittest
 
 from email import message_from_file
@@ -11,6 +12,10 @@ from github2.client import Github
 from github2.request import charset_from_headers
 
 
+if sys.version_info[0] == 2:
+    bytes = lambda x, enc: x
+
+
 HTTP_DATA_DIR = "tests/data/"
 
 ORIG_HTTP_OBJECT = httplib2.Http
@@ -22,7 +27,7 @@ class HttpMock(object):
     Implementation tests should never span network boundaries
     """
 
-    def __init__(self, cache=None, timeout=None, proxy_info=None):
+    def __init__(self, cache=None, timeout=None, proxy_info=None, ca_certs=None):
         """Create a mock httplib.Http object
 
         .. attribute: called_with
@@ -37,7 +42,7 @@ class HttpMock(object):
         if os.path.exists(file):
             response = message_from_file(open(file))
             headers = httplib2.Response(response)
-            body = response.get_payload().encode(charset_from_headers(headers))
+            body = bytes(response.get_payload(), charset_from_headers(headers))
             return (headers, body)
         else:
             return (httplib2.Response({"status": "404"}),
@@ -65,6 +70,19 @@ class HttpMockTestCase(unittest.TestCase):
         httplib2.Http = ORIG_HTTP_OBJECT
 
 
+class HttpMockAuthenticatedTestCase(HttpMockTestCase):
+    def setUp(self):
+        """Prepare test fixtures
+
+        :see: ``HttpMockTestCase``
+
+        :attr:`client` is an authenticated :obj:`Github` object for easy use
+        in tests.
+        """
+        httplib2.Http = HttpMock
+        self.client = Github(access_token='xxx')
+
+
 def set_http_mock():
     """Function to enable ``Http`` mock
 
